@@ -1449,11 +1449,6 @@ QString Formatting::origin(int o)
     }
 }
 
-QString Formatting::deVsString(bool compliant)
-{
-    return DeVSCompliance::name(compliant);
-}
-
 namespace
 {
 QString formatTrustScope(const char *trustScope)
@@ -1534,6 +1529,7 @@ QString Formatting::prettyAlgorithmName(const std::string &algorithm)
         {"nistp256", i18nc("@info", "ECC (NIST P-256)")},
         {"nistp384", i18nc("@info", "ECC (NIST P-384)")},
         {"nistp521", i18nc("@info", "ECC (NIST P-521)")},
+        {"rsa1024", i18nc("@info", "RSA 1024")},
         {"rsa2048", i18nc("@info", "RSA 2048")},
         {"rsa3072", i18nc("@info", "RSA 3072")},
         {"rsa4096", i18nc("@info", "RSA 4096")},
@@ -1545,7 +1541,7 @@ QString Formatting::prettyAlgorithmName(const std::string &algorithm)
         {"elg4096", i18nc("@info", "Elgamal 4096")},
     };
     const auto it = displayNames.find(algorithm);
-    return (it != displayNames.end()) ? it->second : i18nc("@info", "Unknown algorithm");
+    return (it != displayNames.end()) ? it->second : QString::fromStdString(algorithm);
 }
 
 static QString formatValidSignatureWithTrustLevel(const GpgME::UserID &id)
@@ -1594,15 +1590,19 @@ static QString formatSigningInformation(const GpgME::Signature &sig, const GpgME
     const QDateTime dt = sig.creationTime() != 0 ? QDateTime::fromSecsSinceEpoch(quint32(sig.creationTime())) : QDateTime();
 
     if (key.isNull()) {
-        const QString id = u"<br/>"_s + Formatting::prettyID(sig.fingerprint());
+        const auto id =
+            QStringLiteral("<br/><a href='certificate:%1'>%2</a>").arg(QString::fromLatin1(sig.fingerprint()), Formatting::prettyID(sig.fingerprint()));
         if (dt.isValid()) {
-            return i18nc("1 is a date", "Signature created on %1 using an unknown certificate with fingerprint %2", QLocale().toString(dt), id);
+            return i18nc("1 is a date",
+                         "Signature created on %1 using an unknown certificate with fingerprint %2",
+                         QLocale().toString(dt, QLocale::ShortFormat),
+                         id);
         }
         return i18n("Signature created using an unknown certificate with fingerprint %1", id);
     }
 
     if (dt.isValid()) {
-        text += i18nc("1 is a date", "Signature created on %1 with certificate: %2", QLocale().toString(dt), renderKey(key));
+        text += i18nc("1 is a date", "Signature created on %1 with certificate: %2", QLocale().toString(dt, QLocale::ShortFormat), renderKey(key));
     } else {
         text += i18n("Signature created with certificate: %1", renderKey(key));
     }
